# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.0.0-v202407021040-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleTreePathCreatorInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_indexes': 'list[int]',
        'separator': 'str'
    }

    attribute_map = {
        'column_indexes': 'columnIndexes',
        'separator': 'separator'
    }

    def __init__(self, column_indexes=None, separator=None):
        """
        ColumnRuleTreePathCreatorInputV1 - a model defined in Swagger
        """

        self._column_indexes = None
        self._separator = None

        if column_indexes is not None:
          self.column_indexes = column_indexes
        if separator is not None:
          self.separator = separator

    @property
    def column_indexes(self):
        """
        Gets the column_indexes of this ColumnRuleTreePathCreatorInputV1.
        The indexes of the columns whose items will be placed into a tree. A column index is 1-based

        :return: The column_indexes of this ColumnRuleTreePathCreatorInputV1.
        :rtype: list[int]
        """
        return self._column_indexes

    @column_indexes.setter
    def column_indexes(self, column_indexes):
        """
        Sets the column_indexes of this ColumnRuleTreePathCreatorInputV1.
        The indexes of the columns whose items will be placed into a tree. A column index is 1-based

        :param column_indexes: The column_indexes of this ColumnRuleTreePathCreatorInputV1.
        :type: list[int]
        """
        if column_indexes is None:
            raise ValueError("Invalid value for `column_indexes`, must not be `None`")

        self._column_indexes = column_indexes

    @property
    def separator(self):
        """
        Gets the separator of this ColumnRuleTreePathCreatorInputV1.
        The separator between levels of the newly created tree path. Defaults to ' >> '

        :return: The separator of this ColumnRuleTreePathCreatorInputV1.
        :rtype: str
        """
        return self._separator

    @separator.setter
    def separator(self, separator):
        """
        Sets the separator of this ColumnRuleTreePathCreatorInputV1.
        The separator between levels of the newly created tree path. Defaults to ' >> '

        :param separator: The separator of this ColumnRuleTreePathCreatorInputV1.
        :type: str
        """

        self._separator = separator

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleTreePathCreatorInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
